@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -196,13 +196,8 @@ prompt_close (MmaidWindow *mmaid)
       gint result;
       GtkWidget *dialog;
 
-#if GLIB_CHECK_VERSION(2,6,0)
       utf8str = g_filename_display_name
                                     (orz_mdi_get_file (ORZ_MDI (mdi), page));
-#else /* not GLIB_CHECK_VERSION(2,6,0) */
-      utf8str = g_filename_to_utf8
-                (orz_mdi_get_file (ORZ_MDI (mdi), page), -1, NULL, NULL, NULL);
-#endif /* not GLIB_CHECK_VERSION(2,6,0) */
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_NONE,
