@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,7 +46,10 @@ root_dialog_clicked (GtkWidget  *widget,
 
   root = g_strdup (gtk_entry_get_text (GTK_ENTRY (rtdlg->entry)));
   if (root[0] == '\0' || !G_IS_DIR_SEPARATOR (root[g_strlen (root) - 1]))
-#if GTK_CHECK_VERSION(2,6,0)
+#if GTK_CHECK_VERSION(2,24,0)
+    root = gtk_combo_box_text_get_active_text
+                                        (GTK_COMBO_BOX_TEXT (rtdlg->combo));
+#elif GTK_CHECK_VERSION(2,6,0)
     root = gtk_combo_box_get_active_text (GTK_COMBO_BOX (rtdlg->combo));
 #elif GTK_CHECK_VERSION(2,4,0)
     {
@@ -70,8 +73,13 @@ root_dialog_clicked (GtkWidget  *widget,
   dialog = gtk_file_chooser_dialog_new (_("Browse"),
                         GTK_WINDOW (rtdlg->dialog),
                         GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+# ifdef G_OS_WIN32
+                        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#else /* not G_OS_WIN32 */
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                         GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+#endif /* not G_OS_WIN32 */
                         NULL);
   if (path)
     {
@@ -134,7 +142,10 @@ root_dialog_changed (GtkWidget  *widget,
   gint i, count, leng;
   const ID3Tag *id3tag;
 
-#if GTK_CHECK_VERSION(2,6,0)
+#if GTK_CHECK_VERSION(2,24,0)
+  find = gtk_combo_box_text_get_active_text
+                                        (GTK_COMBO_BOX_TEXT (rtdlg->combo));
+#elif GTK_CHECK_VERSION(2,6,0)
   find = gtk_combo_box_get_active_text (GTK_COMBO_BOX (rtdlg->combo));
 #elif GTK_CHECK_VERSION(2,4,0)
     {
@@ -262,10 +273,18 @@ root_dialog (MmaidWindow *mmaid)
         g_free (path);
       }
 #if GTK_CHECK_VERSION(2,4,0)
+# if GTK_CHECK_VERSION(2,24,0)
+  rtdlg.combo = gtk_combo_box_text_new ();
+  for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (rtdlg.combo),
+                                                                glist->data);
+# else /* not GTK_CHECK_VERSION(2,24,0) */
   rtdlg.combo = gtk_combo_box_new_text ();
   for (glist = g_list_first (glist);
                             glist; glist = g_list_delete_link (glist, glist))
     gtk_combo_box_append_text (GTK_COMBO_BOX (rtdlg.combo), glist->data);
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
   gtk_combo_box_set_active (GTK_COMBO_BOX (rtdlg.combo), 0);
   g_signal_connect (G_OBJECT (rtdlg.combo), "changed",
                                     G_CALLBACK (root_dialog_changed), &rtdlg);
@@ -306,8 +325,8 @@ root_dialog (MmaidWindow *mmaid)
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_label_set_mnemonic_widget (GTK_LABEL (label1), rtdlg.entry);
   /* ja:フレームとボックス */
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (rtdlg.dialog));
+  gtk_box_set_spacing (GTK_BOX (vbox), SPACING);
   hbox0 = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox0), label0, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox0), rtdlg.combo, TRUE, TRUE, 0);
@@ -319,7 +338,6 @@ root_dialog (MmaidWindow *mmaid)
   gtk_box_pack_start (GTK_BOX (hbox0), hbox1, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox0), button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox0, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (rtdlg.dialog)->vbox), vbox);
 
   /* ja:表示 */
   gtk_dialog_set_response_sensitive (GTK_DIALOG (rtdlg.dialog),
@@ -339,7 +357,10 @@ root_dialog (MmaidWindow *mmaid)
       gint i, count, leng;
       const ID3Tag *id3tag;
 
-#if GTK_CHECK_VERSION(2,6,0)
+#if GTK_CHECK_VERSION(2,24,0)
+      find = gtk_combo_box_text_get_active_text
+                                            (GTK_COMBO_BOX_TEXT (rtdlg.combo));
+#elif GTK_CHECK_VERSION(2,6,0)
       find = gtk_combo_box_get_active_text (GTK_COMBO_BOX (rtdlg.combo));
 #elif GTK_CHECK_VERSION(2,4,0)
         {
